=== modified file 'src/app/qml/ui/NotePage.qml'
--- src/app/qml/ui/NotePage.qml	2013-11-25 00:49:48 +0000
+++ src/app/qml/ui/NotePage.qml	2013-11-25 19:06:38 +0000
@@ -13,11 +13,7 @@
             width: parent.width
             text: "save"
             onClicked: {
-                print("timer triggered")
-                var content = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><!DOCTYPE en-note SYSTEM \"http://xml.evernote.com/pub/enml2.dtd\"><en-note><div><br clear=\"none\"/>"
-                content = content + noteTextArea.getText(0, noteTextArea.length)
-                content = content + "<br clear=\"none\"/></div><div><br clear=\"none\"/></div></en-note>"
-                note.content = content
+                note.content = noteTextArea.text
                 note.save();
             }
         }

=== modified file 'src/plugin/Evernote/Evernote.pro'
--- src/plugin/Evernote/Evernote.pro	2013-11-25 00:49:48 +0000
+++ src/plugin/Evernote/Evernote.pro	2013-11-25 19:06:38 +0000
@@ -1,7 +1,7 @@
 TARGET=evernoteplugin
 TEMPLATE=lib
 CONFIG = qt plugin
-QT += qml gui
+QT += qml gui xml
 QMAKE_CXXFLAGS += -std=c++0x -fPIC
 
 INCLUDEPATH += ../../../3rdParty/evernote-sdk-cpp/src/ ../../../3rdParty/libthrift
@@ -22,7 +22,8 @@
     jobs/createnotejob.cpp \
     jobs/evernotejob.cpp \
     jobs/savenotejob.cpp \
-    jobs/deletenotejob.cpp
+    jobs/deletenotejob.cpp \
+    utils/html2enmlconverter.cpp
 
 HEADERS += evernoteplugin.h \
     notesstore.h \
@@ -37,7 +38,8 @@
     jobs/createnotejob.h \
     jobs/evernotejob.h \
     jobs/savenotejob.h \
-    jobs/deletenotejob.h
+    jobs/deletenotejob.h \
+    utils/html2enmlconverter.h
 
 message(building in $$OUT_PWD)
 LIBS += -L$$OUT_PWD/../../../3rdParty/evernote-sdk-cpp/ -L$$OUT_PWD/../../../3rdParty/libthrift/ -levernote-sdk-cpp -llibthrift

=== modified file 'src/plugin/Evernote/notesstore.cpp'
--- src/plugin/Evernote/notesstore.cpp	2013-11-25 00:49:48 +0000
+++ src/plugin/Evernote/notesstore.cpp	2013-11-25 19:06:38 +0000
@@ -2,6 +2,7 @@
 #include "notebooks.h"
 #include "notebook.h"
 #include "note.h"
+#include "utils/html2enmlconverter.h"
 
 #include "jobs/fetchnotesjob.h"
 #include "jobs/fetchnotebooksjob.h"
@@ -133,6 +134,10 @@
 void NotesStore::saveNote(const QString &guid)
 {
     Note *note = m_notes.value(guid);
+
+    QString enml = Html2EnmlConverter::html2enml(note->content());
+    note->setContent(enml);
+
     SaveNoteJob *job = new SaveNoteJob(note, this);
     connect(job, &SaveNoteJob::resultReady, this, &NotesStore::saveNoteJobDone);
     m_jobQueue.append(job);

=== added directory 'src/plugin/Evernote/utils'
=== added file 'src/plugin/Evernote/utils/html2enmlconverter.cpp'
--- src/plugin/Evernote/utils/html2enmlconverter.cpp	1970-01-01 00:00:00 +0000
+++ src/plugin/Evernote/utils/html2enmlconverter.cpp	2013-11-25 19:06:38 +0000
@@ -0,0 +1,84 @@
+#include "html2enmlconverter.h"
+
+#include <QXmlStreamReader>
+#include <QXmlStreamWriter>
+#include <QStringList>
+
+// Taken from http://xml.evernote.com/pub/enml2.dtd
+QStringList supportedTags = QStringList() << "a" << "abbr" << "acronym" << "address" << "area" << "b" << "bdo" << "big" <<
+                                             "blockquote" << "br" << "caption" << "center" << "cite" << "code" << "col" <<
+                                             "colgroup" << "dd" << "del" << "dfn" << "div" << "dl" << "dt" << "em" <<
+                                             "en-crypt" << "en-media" << "en-todo" << "font" << "h1" << "h2" << "h3" <<
+                                             "h4" << "h5" << "h6" << "hr" << "i" << "img" << "ins" << "kbd" << "li" <<
+                                             "map" << "ol" << "p" << "pre" << "q" << "s" << "samp" << "small" << "span" <<
+                                             "strike" << "strong" << "sub" << "sup" << "table" << "tbody" << "td" <<
+                                             "tfoot" << "th" << "thead" << "tr" << "tt" << "u" << "ul" << "var";
+
+
+Html2EnmlConverter::Html2EnmlConverter()
+{
+}
+
+QString Html2EnmlConverter::html2enml(const QString &html)
+{
+    // output
+    QString evml;
+    QXmlStreamWriter writer(&evml);
+    writer.writeStartDocument();
+    writer.writeDTD("<!DOCTYPE en-note SYSTEM \"http://xml.evernote.com/pub/enml2.dtd\">");
+
+    // input
+    QXmlStreamReader reader(html);
+
+    // state
+    bool isBody = false;
+
+    while (!reader.atEnd() && !reader.hasError()) {
+        QXmlStreamReader::TokenType token = reader.readNext();
+        if(token == QXmlStreamReader::StartDocument) {
+            continue;
+        }
+
+        // Handle start elements
+        if(token == QXmlStreamReader::StartElement) {
+            // skip everything if body hasn't started yet
+            if (!isBody) {
+                if (reader.name() == "body") {
+                    writer.writeStartElement("en-note");
+                    isBody = true;
+                }
+                continue;
+            }
+            // Write supported start elements to output (including attributes)
+            if (supportedTags.contains(reader.name().toString())) {
+                writer.writeStartElement(reader.name().toString());
+                writer.writeAttributes(reader.attributes());
+            }
+        }
+
+        // Write *all* normal text inside <body> </body> to output
+        if (isBody && token == QXmlStreamReader::Characters) {
+            writer.writeCharacters(reader.text().toString());
+        }
+
+        // handle end elements
+        if (token == QXmlStreamReader::EndElement) {
+
+            // skip everything after body
+            if (reader.name() == "body") {
+                writer.writeEndElement();
+                isBody = false;
+                break;
+            }
+
+            // Write closing tags for supported elements
+            if (supportedTags.contains(reader.name().toString())) {
+                writer.writeEndElement();
+            }
+        }
+    }
+
+    writer.writeEndDocument();
+
+    return evml;
+}

=== added file 'src/plugin/Evernote/utils/html2enmlconverter.h'
--- src/plugin/Evernote/utils/html2enmlconverter.h	1970-01-01 00:00:00 +0000
+++ src/plugin/Evernote/utils/html2enmlconverter.h	2013-11-25 19:06:38 +0000
@@ -0,0 +1,14 @@
+#ifndef HTML2ENMLCONVERTER_H
+#define HTML2ENMLCONVERTER_H
+
+#include <QString>
+
+class Html2EnmlConverter
+{
+public:
+    Html2EnmlConverter();
+
+    static QString html2enml(const QString &html);
+};
+
+#endif // HTML2ENMLCONVERTER_H

